@@ -6,8 +6,6 @@ import java.util.List;
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpiredException;
-import org.gcube.portlets.user.td.gwtservice.shared.history.RollBackSession;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.TableData;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.resources.InternalURITD;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.resources.RemoveResourceSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.resources.ResourceTD;
@@ -24,6 +22,7 @@ import org.gcube.portlets.user.td.resourceswidget.client.properties.ResourceTDDe
 import org.gcube.portlets.user.td.resourceswidget.client.resources.ResourceBundle;
 import org.gcube.portlets.user.td.resourceswidget.client.save.SaveResourceWizard;
 import org.gcube.portlets.user.td.resourceswidget.client.utils.UtilsGXT3;
+import org.gcube.portlets.user.td.widgetcommonevent.client.CommonMessages;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
@@ -60,7 +59,6 @@ import com.sencha.gxt.data.shared.loader.ListLoader;
 import com.sencha.gxt.data.shared.loader.LoadResultListStoreBinding;
 import com.sencha.gxt.widget.core.client.FramedPanel;
 import com.sencha.gxt.widget.core.client.container.MarginData;
-import com.sencha.gxt.widget.core.client.container.VerticalLayoutContainer;
 import com.sencha.gxt.widget.core.client.event.BeforeShowContextMenuEvent;
 import com.sencha.gxt.widget.core.client.event.BeforeShowContextMenuEvent.BeforeShowContextMenuHandler;
 import com.sencha.gxt.widget.core.client.event.SelectEvent;
@@ -84,24 +82,21 @@ import com.sencha.gxt.widget.core.client.menu.MenuItem;
  * 
  */
 public class ResourcesPanel extends FramedPanel {
-	protected String WIDTH = "298px";
-	protected String HEIGHT = "520px";
+	private static final String GRID_RESOURCE_HEIGHT = "300px";
+	private static final String GRID_RESOURCE_WIDTH = "200px";
+	private static final String WIDTH = "298px";
+	private static final String HEIGHT = "520px";
+	
+	private CommonMessages msgsCommon;
+	private ResourcesMessages msgs;
+	
+	private ResourcesDialog parent;
+	private TRId trId;
+	private EventBus eventBus;
 
-	protected ResourcesDialog parent;
-	protected UserInfo userInfo;
-	protected TRId trId;
-	protected TableData table;
-	protected String headingTitle;
-	protected VerticalLayoutContainer vl;
-	protected EventBus eventBus;
-
-	protected ListStore<ResourceTDDescriptor> store;
-	protected ListLoader<ListLoadConfig, ListLoadResult<ResourceTDDescriptor>> loader;
-	protected Grid<ResourceTDDescriptor> grid;
-
-	protected ResourceTDDescriptor currentTDDescriptor;
-	protected int currentRowIndex;
-	protected RollBackSession rollBackSession;
+	private ListStore<ResourceTDDescriptor> store;
+	private ListLoader<ListLoadConfig, ListLoadResult<ResourceTDDescriptor>> loader;
+	private Grid<ResourceTDDescriptor> grid;
 
 	private boolean drawed = false;
 	private Menu contextMenu;
@@ -118,6 +113,7 @@ public class ResourcesPanel extends FramedPanel {
 		this.trId = trId;
 		this.eventBus = eventBus;
 		forceLayoutOnResize = true;
+		initMessages();
 		retrieveUserInfo();
 	}
 
@@ -126,9 +122,15 @@ public class ResourcesPanel extends FramedPanel {
 		this.trId = trId;
 		this.eventBus = eventBus;
 		forceLayoutOnResize = true;
+		initMessages();
 		retrieveUserInfo();
 	}
 
+	protected void initMessages(){
+		msgs = GWT.create(ResourcesMessages.class);
+		msgsCommon = GWT.create(CommonMessages.class);
+	}
+	
 	protected void retrieveUserInfo() {
 		TDGWTServiceAsync.INSTANCE.hello(new AsyncCallback<UserInfo>() {
 
@@ -140,7 +142,7 @@ public class ResourcesPanel extends FramedPanel {
 
 					Log.error("Error Retrieving User Info: "
 							+ caught.getLocalizedMessage());
-					UtilsGXT3.alert("Error", "Error retrieving User Info");
+					UtilsGXT3.alert(msgsCommon.error(), msgs.errorRetrievingUserInfo());
 
 				}
 			}
@@ -187,7 +189,7 @@ public class ResourcesPanel extends FramedPanel {
 								+ "width: 100%; border: none;"
 								+ "font-size: 12px; margin:2px; text-align: left;'>"
 								+ "<tr>"
-								+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'><b>Name: </b></td>"
+								+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'><b>"+msgs.nameLabelFixed()+"</b></td>"
 								+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'>"
 								+ SafeHtmlUtils.htmlEscape(value.getName())
 								+
@@ -195,7 +197,7 @@ public class ResourcesPanel extends FramedPanel {
 								"</td>"
 								+ "</tr>"
 								+ "<tr>"
-								+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'><b>Description: </b></td>"
+								+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'><b>"+msgs.descriptionLabelFixed()+"</b></td>"
 								+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'>"
 								+ SafeHtmlUtils.htmlEscape(value
 										.getDescription())
@@ -204,7 +206,7 @@ public class ResourcesPanel extends FramedPanel {
 								"</td>"
 								+ "</tr>"
 								+ "<tr>"
-								+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'><b>Creation Date: </b></td>"
+								+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'><b>"+msgs.creationDateLabelFixed()+"</b></td>"
 								+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'>"
 								+ SafeHtmlUtils.htmlEscape(value
 										.getCreationDate())
@@ -213,7 +215,7 @@ public class ResourcesPanel extends FramedPanel {
 								"</td>"
 								+ "</tr>"
 								+ "<tr>"
-								+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'><b>Creator Id: </b></td>"
+								+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'><b>"+msgs.creatorIdLabelFixed()+"</b></td>"
 								+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'>"
 								+ new SafeHtmlBuilder()
 										.append(value.getCreatorId())
@@ -223,7 +225,7 @@ public class ResourcesPanel extends FramedPanel {
 								"</td>"
 								+ "</tr>"
 								+ "<tr>"
-								+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'><b>Type: </b></td>"
+								+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'><b>"+msgs.typeLabelFixed()+"</b></td>"
 								+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'>"
 								+ SafeHtmlUtils.htmlEscape(value
 										.getResourceType().toString())
@@ -249,7 +251,7 @@ public class ResourcesPanel extends FramedPanel {
 							if (resource instanceof StringResourceTD) {
 								StringResourceTD stringResourceTD = (StringResourceTD) resource;
 								resourceData = "<tr>"
-										+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'><b>Value: </b></td>"
+										+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'><b>"+msgs.valueLabelFixed()+"</b></td>"
 										+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'>"
 										+ SafeHtmlUtils
 												.htmlEscape(stringResourceTD
@@ -260,7 +262,7 @@ public class ResourcesPanel extends FramedPanel {
 								if (resource instanceof TableResourceTD) {
 									TableResourceTD tableResourceTD = (TableResourceTD) resource;
 									resourceData = "<tr>"
-											+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'><b>Table Id: </b></td>"
+											+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'><b>"+msgs.tableIdLabelFixed()+"</b></td>"
 											+ "<td style='font-size: 12px; padding: 2px 1px 1px 1px;'>"
 											+ new SafeHtmlBuilder()
 													.append(tableResourceTD
@@ -281,7 +283,7 @@ public class ResourcesPanel extends FramedPanel {
 				});
 
 		ColumnConfig<ResourceTDDescriptor, String> nameCol = new ColumnConfig<ResourceTDDescriptor, String>(
-				props.name(), 142, "Name");
+				props.name(), 142, msgs.nameCol());
 
 		nameCol.setCell(new AbstractCell<String>() {
 
@@ -296,7 +298,7 @@ public class ResourcesPanel extends FramedPanel {
 		});
 
 		ColumnConfig<ResourceTDDescriptor, ResourceTDType> typeColumn = new ColumnConfig<ResourceTDDescriptor, ResourceTDType>(
-				props.resourceType(), 30, "Type");
+				props.resourceType(), 30, msgs.typeCol());
 
 		ResourceTDTypeButtonCell button = new ResourceTDTypeButtonCell();
 		button.addSelectHandler(new SelectHandler() {
@@ -369,7 +371,7 @@ public class ResourcesPanel extends FramedPanel {
 
 		grid.setLoader(loader);
 		grid.setSelectionModel(sm);
-		grid.setSize("200px", "300px");
+		grid.setSize(GRID_RESOURCE_WIDTH, GRID_RESOURCE_HEIGHT);
 		grid.getView().setStripeRows(true);
 		grid.getView().setColumnLines(true);
 		grid.getView().setAutoFill(true);
@@ -378,7 +380,7 @@ public class ResourcesPanel extends FramedPanel {
 		grid.setColumnReordering(true);
 		grid.setColumnResize(true);
 		grid.getView().setAutoExpandColumn(nameCol);
-		grid.getView().setEmptyText("Empty");
+		grid.getView().setEmptyText(msgs.gridEmptyText());
 
 		expander.initPlugin(grid);
 
@@ -393,7 +395,7 @@ public class ResourcesPanel extends FramedPanel {
 		contextMenu = new Menu();
 
 		openItem = new MenuItem();
-		openItem.setText("Open");
+		openItem.setText(msgs.itemOpenText());
 		openItem.setIcon(ResourceBundle.INSTANCE.resources());
 		openItem.addSelectionHandler(new SelectionHandler<Item>() {
 
@@ -408,7 +410,7 @@ public class ResourcesPanel extends FramedPanel {
 		});
 
 		saveItem = new MenuItem();
-		saveItem.setText("Save");
+		saveItem.setText(msgs.itemSaveText());
 		saveItem.setIcon(ResourceBundle.INSTANCE.save());
 		saveItem.addSelectionHandler(new SelectionHandler<Item>() {
 
@@ -423,7 +425,7 @@ public class ResourcesPanel extends FramedPanel {
 		});
 
 		removeItem = new MenuItem();
-		removeItem.setText("Delete");
+		removeItem.setText(msgs.itemDeleteText());
 		removeItem.setIcon(ResourceBundle.INSTANCE.delete());
 		removeItem.addSelectionHandler(new SelectionHandler<Item>() {
 
@@ -565,7 +567,7 @@ public class ResourcesPanel extends FramedPanel {
 			public void onSuccess() {
 
 				SaveResourceWizard saveResourceWizard = new SaveResourceWizard(
-						saveResourceSession, "Save Resource", eventBus);
+						saveResourceSession, msgs.saveResourceWizardHead(), eventBus);
 
 				saveResourceWizard.addListener(new WizardListener() {
 
@@ -618,13 +620,13 @@ public class ResourcesPanel extends FramedPanel {
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
+								UtilsGXT3.alert(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage());
 							} else {
 								Log.error("Error removing the resource: "
 										+ caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error",
-										"Error removing the resource: "
+								UtilsGXT3.alert(msgsCommon.error(),
+										msgs.errorRetrievingResourcesFixed()
 												+ caught.getLocalizedMessage());
 							}
 						}
@@ -695,8 +697,8 @@ public class ResourcesPanel extends FramedPanel {
 							} else {
 								Log.error("Error with uri resolver: "
 										+ caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error",
-										"Error retrieving uri from resolver");
+								UtilsGXT3.alert(msgsCommon.error(),
+										msgs.errorRetrievingURIFromResolver());
 							}
 						}
 
@@ -725,8 +727,8 @@ public class ResourcesPanel extends FramedPanel {
 									Log.error("Error with uri resolver: "
 											+ caught.getLocalizedMessage());
 									UtilsGXT3
-											.alert("Error",
-													"Error retrieving uri from resolver");
+											.alert(msgsCommon.error(),
+													msgs.errorRetrievingURIFromResolver());
 								}
 							}
 
@@ -743,8 +745,8 @@ public class ResourcesPanel extends FramedPanel {
 
 				} else {
 					Log.error("Error with resource: no valid resource");
-					UtilsGXT3.alert("Error with resource",
-							"Error no valid InternalUri");
+					UtilsGXT3.alert(msgsCommon.error(),
+							msgs.errorNoValidInternalUri());
 
 				}
 
@@ -772,8 +774,8 @@ public class ResourcesPanel extends FramedPanel {
 							} else {
 								Log.error("Error with uri resolver: "
 										+ caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error",
-										"Error retrieving uri from resolver");
+								UtilsGXT3.alert(msgsCommon.error(),
+										msgs.errorRetrievingURIFromResolver());
 							}
 						}
 
@@ -792,8 +794,8 @@ public class ResourcesPanel extends FramedPanel {
 
 				} else {
 					Log.error("Error with resource: no valid resource");
-					UtilsGXT3.alert("Error with resource",
-							"Error no valid InternalUri");
+					UtilsGXT3.alert(msgsCommon.error(),
+							msgs.errorNoValidInternalUri());
 
 				}
 
@@ -814,12 +816,12 @@ public class ResourcesPanel extends FramedPanel {
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
+								UtilsGXT3.alert(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage());
 							} else {
 								Log.error("Error Retrieving Resources: "
 										+ caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error retrieving resources",
+								UtilsGXT3.alert(msgs.errorRetrievingResourcesHead(),
 										caught.getLocalizedMessage());
 							}
 						}
@@ -857,13 +859,13 @@ public class ResourcesPanel extends FramedPanel {
 				} else {
 					if (caught instanceof TDGWTIsLockedException) {
 						Log.error(caught.getLocalizedMessage());
-						UtilsGXT3.alert("Error Locked",
+						UtilsGXT3.alert(msgsCommon.errorLocked(),
 								caught.getLocalizedMessage());
 					} else {
 						Log.error("Error retrieving current TRId: "
 								+ caught.getLocalizedMessage());
-						UtilsGXT3.alert("Error",
-								"Error retrieving current tabular resource id");
+						UtilsGXT3.alert(msgsCommon.error(),
+								msgs.errorRetrievingCurrentTabularResourceId());
 					}
 				}
 			}
